@@ -490,7 +490,7 @@ flush.console()
 Hessian <- symmpart(jacobian(Score, thetas, method="simple"))
 rownames(Hessian)<-colnames(Hessian)<-names(thetas)
 #std_errors <- c(sqrt(diag(solve(Hessian))))
-if(class(try(chol(Hessian),silent=TRUE))=="try-error") cat("\nWarning: Hessian not positive-definite\n")
+if(inherits(try(chol(Hessian),silent=TRUE), "try-error")) cat("\nWarning: Hessian not positive-definite\n")
 }
 
 model.matrices=list(X=R_X,Y=R_Y,Z=R_Z,G=G,eta=eta.hat,beta=rbetas)
